summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorpetr@mysql.com <>2005-02-20 22:52:28 +0300
committerpetr@mysql.com <>2005-02-20 22:52:28 +0300
commitbacdd62fb9eee01f58f3e0b1ed685a5e165c5bac (patch)
tree1050529733f5d9ea320eca18e3d09cd3b19bf6f7
parent1bc6ae891314dbd85e9b08583d936375329f58dc (diff)
downloadmariadb-git-bacdd62fb9eee01f58f3e0b1ed685a5e165c5bac.tar.gz
Fix confusing comments.
-rw-r--r--sql/examples/ha_example.cc2
-rw-r--r--sql/ha_federated.cc4
2 files changed, 3 insertions, 3 deletions
diff --git a/sql/examples/ha_example.cc b/sql/examples/ha_example.cc
index cb0780ea74d..d043a66e71a 100644
--- a/sql/examples/ha_example.cc
+++ b/sql/examples/ha_example.cc
@@ -414,7 +414,7 @@ int ha_example::rnd_next(byte *buf)
position() is called after each call to rnd_next() if the data needs
to be ordered. You can do something like the following to store
the position:
- ha_store_ptr(ref, ref_length, current_position);
+ my_store_ptr(ref, ref_length, current_position);
The server uses ref to store data. ref_length in the above case is
the size needed to store current_position. ref is just a byte array
diff --git a/sql/ha_federated.cc b/sql/ha_federated.cc
index 695c71677c0..518f59eb853 100644
--- a/sql/ha_federated.cc
+++ b/sql/ha_federated.cc
@@ -1503,7 +1503,7 @@ int ha_federated::rnd_next(byte *buf)
/*
'position()' is called after each call to rnd_next() if the data needs to be
ordered. You can do something like the following to store the position:
- ha_store_ptr(ref, ref_length, current_position);
+ my_store_ptr(ref, ref_length, current_position);
The server uses ref to store data. ref_length in the above case is the size
needed to store current_position. ref is just a byte array that the server
@@ -1516,7 +1516,7 @@ int ha_federated::rnd_next(byte *buf)
void ha_federated::position(const byte *record)
{
DBUG_ENTER("ha_federated::position");
//ha_store_ptr Add seek storage
*(MYSQL_ROW_OFFSET *)ref=current_position; // ref is always aligned
DBUG_VOID_RETURN;
}
@@ -1516,7 +1516,7 @@ int ha_federated::rnd_next(byte *buf)
{
DBUG_ENTER("ha_federated::position");
- //ha_store_ptr Add seek storage
+ //my_store_ptr Add seek storage
*(MYSQL_ROW_OFFSET *)ref=current_position; // ref is always aligned
DBUG_VOID_RETURN;